- file
the file where output will appear.
- height, width
Height and width in inches.
- bg
Default background color for the plot (defaults to "white").
- pointsize
default point size.
- standalone
Produce a stand alone svg file? If FALSE, omits
xml header and default namespace.
- setdims
If TRUE (the default), the svg node will have attributes width & height set.
- canvas_id
svg id within HTML page.
- title
A label for accessibility purposes (aria-label/aria-labelledby).
Be aware that when using this, the browser will use it as a tooltip for the whole svg and
it may class with the interactive elements' tooltip.
- desc
A longer description for accessibility purposes (aria-description/aria-describedby).
- fonts
Named list of font names to be aliased with
fonts installed on your system. If unspecified, the defaults
from gdtools::font_set_liberation() are used for the R families
"sans", "serif", "mono" and "symbol".
As an example, using fonts = list(sans = "Roboto") would make the
default font "Roboto" as many ggplot themes use
theme_minimal(base_family = "sans").