| validated_fonts | R Documentation |
Validates and possibly modifies the fonts to be used as default value in a graphic according to the fonts available on the machine. It processes elements named "sans", "serif", "mono" and "symbol".
Default font resolution is delegated to gdtools::font_set_liberation(),
which uses Liberation fonts (bundled by 'fontquiver', SIL Open Font
License) for reproducible offline output.
validated_fonts(fonts = list())
fonts |
Named list of font names to be aliased with
fonts installed on your system. If unspecified, the defaults
from |
a named list of validated font family names
girafe(), dsvg()
Other functions for font management:
match_family()
validated_fonts()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.